==> klaro-7.x-1.0.tar.gz: klaro/klaro.api.php <==
<?php

/**
 * @file
 * Hooks for klaro module.
 */

/**
 * Add own implementation for klaro.
 *
 * With this hook you can create your own services
 * managed by klaro module.
 * The attribute-string must be identically to
 * the Data Processing Services in klaro UI.
 * For callback-examples see klaro_callback_gtm()
 * in klaro.module.
 *
 * @return array
 *   The array of information about your implementation.
 */
function hook_klaro_info() {
  $result = [];
  $result['myservice'] = [
    'title' => 'My Service',
    'description' => 'Implementation for my service.',
    'info_link' => 'https://example.org',
    'privacy_link' => 'https://example.org/privacy',
    'klaro' => [
      'purposes' => ['statistics'],
      'cookies' => ['/^my_cookie/i'],
      'default' => TRUE,
      'callback' => '',
    ],
    'callback' => 'mymodule_callback_myservice',
  ];
  return $result;
}

/**
 * Alter existing implementations.
 *
 * If you want to override the callback-function of an existing
 * implementation or to change the attribute programmatically
 * you can use this alter-hook.
 *
 * @param array $implementations
 *   A multidimensional array of implementations.
 */
function hook_klaro_info_alter(array &$implementations) {
  // Override data-attribute for my own matomo service.
  if (isset($implementations['matomo'])) {
    $implementations['matomo']['attribute'] = 'My Matomo Service';
  }
}

/**
 * Example-Callback-function.
 *
 * @param string $type
 *   Callback is called twice: 1st hook_js_alter, 2nd hook_pre_render_scripts.
 * @param array $script
 *   The script-Array, depending von $ype.
 *
 * @return bool
 *   TRUE means: klaro-script found.
 */
function example_klaro_callback($type, array $script) {
  switch ($type) {
    case 'js_alter':
      if (isset($script['data'])) {
        if (strpos($script['data'], 'my-js-file.js') !== FALSE) {
          return TRUE;
        }
      }
      break;

    case 'pre_render_scripts':
      if (isset($script['#attributes']['src'])) {
        if (strpos($script['#attributes']['src'], 'my-js-file.js') !== FALSE) {
          return TRUE;
        }
      }
      break;
  }
  return FALSE;
}

==> klaro-7.x-1.1.tar.gz: klaro/klaro.api.php <==
<?php

/**
 * @file
 * Hooks for klaro module.
 */

/**
 * Add own implementation for klaro.
 *
 * With this hook you can create your own services
 * managed by klaro module.
 * The attribute-string must be identically to
 * the Data Processing Services in klaro UI.
 * For callback-examples see klaro_callback_gtm()
 * in klaro.module.
 *
 * @return array
 *   The array of information about your implementation.
 */
function hook_klaro_info() {
  $result = [];
  $result['myservice'] = [
    'title' => 'My Service',
    'description' => 'Implementation for my service.',
    'info_link' => 'https://example.org',
    'privacy_link' => 'https://example.org/privacy',
    'klaro' => [
      'purposes' => ['statistics'],
      'cookies' => ['/^my_cookie/i'],
      'default' => TRUE,
      'required' => FALSE,
      'callback' => '',
    ],
    'callback' => 'mymodule_callback_myservice',
  ];
  return $result;
}

/**
 * Alter existing implementations.
 *
 * If you want to override the callback-function of an existing
 * implementation or to change the attribute programmatically
 * you can use this alter-hook.
 *
 * @param array $implementations
 *   A multidimensional array of implementations.
 */
function hook_klaro_info_alter(array &$implementations) {
  // Override title for my own matomo service.
  if (isset($implementations['matomo'])) {
    $implementations['matomo']['title'] = 'My Matomo Service';
  }
}

/**
 * Example-Callback-function.
 *
 * The callback is called twice:
 * 1. hook_js_alter:
 * Disable preprocessing (JS-aggregation).
 * 2. hook_pre_render_scripts:
 * Replace type and add data-attributes.
 * For further examples see klaro_callback_*() in klaro.module.
 *
 * @param string $type
 *   Kind of callback (hook_js_alter or hook_pre_render_scripts).
 * @param array $script
 *   The script-Array, depending von $ype.
 *
 * @return bool
 *   TRUE means: klaro-script found.
 */
function example_klaro_callback($type, array $script) {
  switch ($type) {
    case 'js_alter':
      // External JS.
      if (isset($script['data'])) {
        if (strpos($script['data'], 'my-js-file.js') !== FALSE) {
          return TRUE;
        }
      }
      // Inline JS.
      if (isset($script['data'])) {
        if (strpos($script['data'], 'var _paq') === 0) {
          return TRUE;
        }
      }
      break;

    case 'pre_render_scripts':
      // External JS.
      if (isset($script['#attributes']['src'])) {
        if (strpos($script['#attributes']['src'], 'my-js-file.js') !== FALSE) {
          return TRUE;
        }
      }
      // Inline JS.
      if (isset($script['#value'])) {
        if (strpos($script['#value'], 'var _paq') === 0) {
          return TRUE;
        }
      }
      break;
  }
  return FALSE;
}
